!       angle in the config file is in degree; (e.g  sin(90.)  is 1.0)
#define DEGANGLE
!       if f90 is available, USEFORMULA will permit to use
!        mathmatical formula in config file
#undef  USEFORMULA

#undef  LightINTINFO
#undef  OtherINTINFO
